@@ -1,4 +1,5 @@
 import os
+import sys
 
 import numpy as np
 import pandas as pd
@@ -45,7 +46,14 @@ def get_station(args, input_file, stations):
     """Get latitude, longitude and name for each station"""
     filename = os.path.basename(input_file)
     name = filename[:9]
-    lat, lon, new_name = common.parse_station(args, stations[name])
+    try:
+        lat, lon, new_name = common.parse_station(args, stations[name])
+    except KeyError as err:
+        print('KeyError: {}'.format(err))
+        print('HINT: This KeyError can occur when JAWS is asked to process station that is not in its database. '
+              'Please inform the JAWS maintainers by opening an issue at https://github.com/jaws/jaws/issues.')
+        sys.exit(1)
+
     return lat, lon, new_name
 
 
